@@ -66,39 +66,7 @@ enum
   COLUMN_LAST
 };
 
-
-static gpointer parent_class;
-
-GType
-gm_audio_profiles_edit_get_type (void)
-{
-  static GType object_type = 0;
-
-  g_type_init ();
-
-  if (!object_type)
-  {
-    static const GTypeInfo object_info =
-    {
-      sizeof (GMAudioProfilesEditClass),
-      (GBaseInitFunc) NULL,
-      (GBaseFinalizeFunc) NULL,
-      (GClassInitFunc) gm_audio_profiles_edit_class_init,
-      NULL,           /* class_finalize */
-      NULL,           /* class_data */
-      sizeof (GMAudioProfilesEdit),
-      0,              /* n_preallocs */
-      (GInstanceInitFunc) gm_audio_profiles_edit_init,
-    };
-
-    object_type = g_type_register_static (GTK_TYPE_DIALOG,
-                                          "GMAudioProfilesEdit",
-                                          &object_info, 0);
-  }
-
-  return object_type;
-}
-
+G_DEFINE_TYPE (GMAudioProfilesEdit, gm_audio_profiles_edit, GTK_TYPE_DIALOG);
 
 /* register custom edit stock icon */
 static void
@@ -111,7 +79,7 @@ gm_audio_profile_manage_register_stock (void)
     GtkIconFactory *factory;
     GtkIconSet     *icons;
 
-    static GtkStockItem edit_item [] = {
+    const GtkStockItem edit_item [] = {
       { MANAGE_STOCK_EDIT, N_("_Edit"), 0, 0, GETTEXT_PACKAGE },
     };
 
@@ -125,6 +93,35 @@ gm_audio_profile_manage_register_stock (void)
 }
 
 /* widget callbacks */
+
+static void
+count_selected_profiles_func (GtkTreeModel      *model,
+                              GtkTreePath       *path,
+                              GtkTreeIter       *iter,
+                              gpointer           data)
+{
+  int *count = data;
+
+  *count += 1;
+}
+
+static void
+selection_changed_callback (GtkTreeSelection *selection,
+                            GMAudioProfilesEditPrivate *priv)
+{
+  int count;
+
+  count = 0;
+  gtk_tree_selection_selected_foreach (selection,
+                                       count_selected_profiles_func,
+                                       &count);
+
+  gtk_widget_set_sensitive (priv->edit_button,
+                            count == 1);
+  gtk_widget_set_sensitive (priv->delete_button,
+                            count > 0);
+}
+
 static void
 profile_activated_callback (GtkTreeView       *tree_view,
                             GtkTreePath       *path,
@@ -134,6 +131,7 @@ profile_activated_callback (GtkTreeView       *tree_view,
   GMAudioProfile *profile;
   GtkTreeIter iter;
   GtkTreeModel *model;
+  GtkWidget *edit_dialog;
 
   model = gtk_tree_view_get_model (tree_view);
 
@@ -146,9 +144,15 @@ profile_activated_callback (GtkTreeView       *tree_view,
                       COLUMN_PROFILE_OBJECT,
                       &profile,
                       -1);
-  if (profile)
-  /* FIXME: is this the right function name ? */
-  gm_audio_profile_edit_new ((GConfClient *)profile, gm_audio_profile_get_id (profile));
+  if (profile) {
+    /* FIXME: is this the right function name ? */
+    edit_dialog = gm_audio_profile_edit_new ((GConfClient *) profile, gm_audio_profile_get_id (profile));
+    g_return_if_fail (edit_dialog != NULL);
+    gtk_widget_show_all (GTK_WIDGET (edit_dialog));
+    gtk_dialog_run (GTK_DIALOG (edit_dialog));
+  } else {
+    g_warning ("Could not retrieve profile");
+  }
 }
 
 static void
@@ -374,6 +378,7 @@ edit_button_clicked (GtkWidget   *button,
   /* only one selection ? */
   if (profiles->next == NULL)
   {
+    GtkWidget *edit_dialog;	  
     profile = (GMAudioProfile *) profiles->data;
     /* connect to profile changed signal so we can update the name in the list
      * if it gets changed */
@@ -382,8 +387,11 @@ edit_button_clicked (GtkWidget   *button,
                              dialog->priv->manage_profiles_list, 0);
 
     /* FIXME: is this the right function name ? */
-    gm_audio_profile_edit_new ((GConfClient *)profile, gm_audio_profile_get_id (profile));
-                      //GTK_WINDOW (dialog));
+    edit_dialog = gm_audio_profile_edit_new ((GConfClient *)profile, gm_audio_profile_get_id (profile));
+                       //GTK_WINDOW (dialog));
+    g_return_if_fail (edit_dialog != NULL);
+    gtk_widget_show_all (GTK_WIDGET (edit_dialog));
+    gtk_dialog_run (GTK_DIALOG(edit_dialog));
   }
   else
   {
@@ -447,12 +455,6 @@ delete_button_clicked (GtkWidget   *button,
                                        list_selected_profiles_func,
                                        &deleted_profiles);
 
-  if (deleted_profiles == NULL)
-  {
-    gmp_util_show_error_dialog (dialog->priv->transient_parent, NULL, _("You must select one or more profiles to delete."));
-    return;
-  }
-
   count = g_list_length (deleted_profiles);
   if (count > 1)
   {
@@ -481,7 +483,7 @@ delete_button_clicked (GtkWidget   *button,
                      gm_audio_profile_get_name (deleted_profiles->data));
   }
 
-  confirm_dialog = gtk_message_dialog_new (dialog->priv->transient_parent,
+  confirm_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
                                    GTK_MESSAGE_QUESTION,
                                    GTK_BUTTONS_NONE,
@@ -507,9 +509,10 @@ delete_button_clicked (GtkWidget   *button,
 
   g_signal_connect (G_OBJECT (confirm_dialog), "response",
                     G_CALLBACK (delete_confirm_response),
-                    dialog->priv->transient_parent);
-
+                    dialog);
+  g_return_if_fail (confirm_dialog != NULL);
   gtk_widget_show_all (confirm_dialog);
+  gtk_dialog_run (GTK_DIALOG (confirm_dialog));
 }
 
 /* ui callbacks */
@@ -518,28 +521,26 @@ on_gm_audio_profiles_edit_response (GtkWidget *dialog,
                                int        id,
                                void      *data)
 {
-/* FIXME: add help
   if (id == GTK_RESPONSE_HELP)
     {
-      GError *err;
-      err = NULL;
-      gnome_help_display ("gnome-terminal", "gnome-terminal-manage-profiles",
-                          &err);
+      GError *err = NULL;
+
+      gnome_help_display_on_screen ("gnome-audio-profiles",
+                                    "gnome-audio-profiles-profile-edit",
+				    gtk_widget_get_screen (GTK_WIDGET (dialog)),
+				    &err);
+
 
       if (err)
         {
-          terminal_util_show_error_dialog (GTK_WINDOW (app->manage_profiles_dialog), NULL,
-                                           _("There was an error displaying help: %s"),
-                                           err->message);
+          gmp_util_show_error_dialog  (GTK_WINDOW (dialog), NULL,
+                                       _("There was an error displaying help: %s"), err->message);
           g_error_free (err);
         }
+      return;
     }
-  else
-*/
-    {
-      GMP_DEBUG("destroying dialog widget\n");
-      gtk_widget_destroy (GTK_WIDGET (dialog));
-    }
+      
+    gtk_widget_destroy (dialog);
 }
 
 static void
@@ -571,17 +572,19 @@ gm_audio_profiles_list_notify (GConfClient *client,
 static void
 gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
 {
+  GtkDialog *gdialog = GTK_DIALOG (dialog);
   GtkWidget *vbox;
   GtkWidget *label;
   GtkWidget *sw;
   GtkWidget *hbox;
+  GtkWidget *bbox;
   GtkWidget *button;
   GtkWidget *spacer;
   GtkRequisition req;
-  GtkSizeGroup *size_group;
   GtkTreeSelection *selection;
 
-  dialog->priv = g_new0 (GMAudioProfilesEditPrivate, 1);
+  dialog->priv = G_TYPE_INSTANCE_GET_PRIVATE (dialog, GM_AUDIO_TYPE_PROFILES_EDIT, GMAudioProfilesEditPrivate);
+
   /*
   dialog =
     gtk_dialog_new_with_buttons (_("Edit Profiles"),
@@ -594,14 +597,21 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
                                  NULL);
   */
                                  // FIXME: GTK_DIALOG_DESTROY_WITH_PARENT,
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Edit GMAudio Profiles"));
+  gtk_window_set_title (GTK_WINDOW (dialog), _("Edit GNOME Audio Profiles"));
+  gtk_window_set_default_size (GTK_WINDOW (dialog), 320, 240);
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
                                  GTK_STOCK_HELP,
                                  GTK_RESPONSE_HELP,
                                  GTK_STOCK_CLOSE,
                                  GTK_RESPONSE_ACCEPT,
                                  NULL);
-   gtk_dialog_set_default_response (GTK_DIALOG (dialog),                                       GTK_RESPONSE_ACCEPT);
+
+  gtk_dialog_set_has_separator (gdialog, FALSE);
+  gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+  gtk_box_set_spacing (GTK_BOX (gdialog->vbox), 2); /* 2 * 5 + 2 = 12 */
+  gtk_container_set_border_width (GTK_CONTAINER (gdialog->action_area), 5);
+  gtk_box_set_spacing (GTK_BOX (gdialog->action_area), 6);
+
   g_signal_connect (GTK_DIALOG (dialog),
                     "response",
                     G_CALLBACK (on_gm_audio_profiles_edit_response),
@@ -612,11 +622,9 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
                     G_CALLBACK (on_gm_audio_profiles_edit_destroy),
                     NULL);
 
-#define PADDING 5
-
-  vbox = gtk_vbox_new (FALSE, PADDING);
-  gtk_container_set_border_width (GTK_CONTAINER (vbox), PADDING);
-  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+  vbox = gtk_vbox_new (FALSE, 6);
+  gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
+  gtk_box_pack_start (GTK_BOX (gdialog->vbox),
                       vbox, TRUE, TRUE, 0);
 
   /* FIXME
@@ -636,21 +644,14 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
                     app->manage_profiles_default_menu, FALSE, FALSE, 0);
   */
 
-  hbox = gtk_hbox_new (FALSE, PADDING);
+  label = gtk_label_new_with_mnemonic (_("_Profiles:"));
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+
+  hbox = gtk_hbox_new (FALSE, 6);
   gtk_box_pack_start (GTK_BOX (vbox),
                       hbox, TRUE, TRUE, 0);
 
-  vbox = gtk_vbox_new (FALSE, PADDING);
-  gtk_box_pack_start (GTK_BOX (hbox),
-                      vbox, TRUE, TRUE, 0);
-
-  size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
-
-
-  label = gtk_label_new_with_mnemonic (_("_Profiles:"));       gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-  gtk_size_group_add_widget (size_group, label);
-  gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
-
   dialog->priv->manage_profiles_list = create_profile_list ();
 
   g_signal_connect (G_OBJECT (dialog->priv->manage_profiles_list),
@@ -670,27 +671,23 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw),
                                        GTK_SHADOW_IN);
 
-  gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (hbox), sw, TRUE, TRUE, 0);
 
   gtk_container_add (GTK_CONTAINER (sw), dialog->priv->manage_profiles_list);
 
-  gtk_dialog_set_default_response (GTK_DIALOG (dialog),                                       RESPONSE_CREATE);
+  gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
 
   gtk_label_set_mnemonic_widget (GTK_LABEL (label),
                                  dialog->priv->manage_profiles_list);
 
-  vbox = gtk_vbox_new (FALSE, PADDING);
-  gtk_box_pack_start (GTK_BOX (hbox),
-                      vbox, FALSE, FALSE, 0);
-
-  spacer = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
-  gtk_size_group_add_widget (size_group, spacer);
-  gtk_box_pack_start (GTK_BOX (vbox),
-                      spacer, FALSE, FALSE, 0);
+  bbox = gtk_vbutton_box_new ();
+  gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
+  gtk_box_set_spacing (GTK_BOX (bbox), 6);
+  gtk_box_pack_end (GTK_BOX (hbox), bbox, FALSE, FALSE, 0);
 
   button = gtk_button_new_from_stock (GTK_STOCK_NEW);
   fix_button_align (button);
-  gtk_box_pack_start (GTK_BOX (vbox),
+  gtk_box_pack_start (GTK_BOX (bbox),
                       button, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (new_button_clicked), dialog);
@@ -704,10 +701,11 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
 
   button = gtk_button_new_from_stock (MANAGE_STOCK_EDIT);
   fix_button_align (button);
-  gtk_box_pack_start (GTK_BOX (vbox),
+  gtk_box_pack_start (GTK_BOX (bbox),
                      button, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (edit_button_clicked), dialog);
+  gtk_widget_set_sensitive (button, FALSE);
   dialog->priv->edit_button = button;
 /*
   terminal_util_set_atk_name_description (app->manage_profiles_edit_button, NULL,
@@ -716,37 +714,26 @@ gm_audio_profiles_edit_init (GMAudioProfilesEdit *dialog)
 
   button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
   fix_button_align (button);
-  gtk_box_pack_start (GTK_BOX (vbox),
+  gtk_box_pack_start (GTK_BOX (bbox),
                       button, FALSE, FALSE, 0);
   g_signal_connect (G_OBJECT (button), "clicked",
                     G_CALLBACK (delete_button_clicked), dialog);
+  gtk_widget_set_sensitive (button, FALSE);
   dialog->priv->delete_button = button;
 /*
   terminal_util_set_atk_name_description (app->manage_profiles_delete_button, NULL,
                                           _("Click to delete selected profile"));
   */
 
-  /* Set default size of profile list */
-  gtk_window_set_geometry_hints (GTK_WINDOW (dialog),
-                                 dialog->priv->manage_profiles_list,                                      NULL, 0);
-
-  /* Incremental reflow makes this a bit useless, I guess. */
-  gtk_widget_size_request (dialog->priv->manage_profiles_list, &req);
-
-  gtk_window_set_default_size (GTK_WINDOW (dialog),
-                               MIN (req.width + 140, 450),
-                               MIN (req.height + 190, 400));
-
   gtk_widget_grab_focus (dialog->priv->manage_profiles_list);
-  g_object_unref (G_OBJECT (size_group));       /* Monitor selection for sensitivity */
+
+  /* Monitor selection for sensitivity */
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->priv->manage_profiles_list));
-  /* FIXME: callback for changed
-  selection_changed_callback (selection, app);
+
+  selection_changed_callback (selection, dialog->priv);
   g_signal_connect (G_OBJECT (selection), "changed",
                     G_CALLBACK (selection_changed_callback),
-                    app);
-  */
-
+                    dialog->priv);
 }
 
 static void
@@ -754,9 +741,9 @@ gm_audio_profiles_edit_class_init (GMAudioProfilesEditClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_peek_parent (klass);
-
   object_class->finalize = gm_audio_profiles_edit_finalize;
+
+  g_type_class_add_private (object_class, sizeof (GMAudioProfilesEditPrivate));
 }
 
 static void
@@ -765,10 +752,7 @@ gm_audio_profiles_edit_finalize (GObject *object)
   GMAudioProfilesEdit *dialog;
 
   dialog = GM_AUDIO_PROFILES_EDIT (object);
-
-  g_free (dialog->priv);
-
-  G_OBJECT_CLASS (parent_class)->finalize (object);
+  G_OBJECT_CLASS (gm_audio_profiles_edit_parent_class)->finalize (object);
 }
 
 GtkWidget*
@@ -874,7 +858,7 @@ new_profile_response_callback (GtkWidget *new_profile_dialog,
     }
     if (tmp)
     {
-      gmp_util_show_error_dialog (GTK_WINDOW (new_profile_dialog), NULL,
+      gmp_util_run_error_dialog (GTK_WINDOW (new_profile_dialog),
                                    _("You already have a profile called \"%s\""), name);
       goto cleanup;
     }
@@ -899,7 +883,7 @@ new_profile_response_callback (GtkWidget *new_profile_dialog,
     if (error)
     {
       g_print ("ERROR: %s\n", error->message);
-      gmp_util_show_error_dialog (GTK_WINDOW (transient_parent), NULL,
+      gmp_util_run_error_dialog (GTK_WINDOW (transient_parent),
                                   _("GConf Error (FIXME): %s\n"),
                                   error->message);
       g_error_free (error);
@@ -955,6 +939,7 @@ gm_audio_profiles_edit_new_profile (GMAudioProfilesEdit *dialog,
 {
   GtkWindow *old_transient_parent;
   GtkWidget *create_button;
+  gint response;
 
   if (dialog->priv->new_profile_dialog == NULL)
   {
@@ -1030,4 +1015,9 @@ gm_audio_profiles_edit_new_profile (GMAudioProfilesEdit *dialog,
 
   gtk_widget_show_all (dialog->priv->new_profile_dialog);
   gtk_window_present (GTK_WINDOW (dialog->priv->new_profile_dialog));
+  
+  //keep running the dialog until the response is GTK_RESPONSE_NONE
+  do {
+    response = gtk_dialog_run (GTK_DIALOG (dialog->priv->new_profile_dialog));
+  } while (response != GTK_RESPONSE_NONE);
 }
